@@ -12,8 +12,8 @@ class XTrain:
 
 @pytest.fixture
 def trained_model():
-    """ Trained model object """
-    return TrainedModel()
+    """ Serialized trained model """
+    return "job.joblib"
 
 
 @pytest.fixture
